@@ -176,7 +176,7 @@ def zip_attachment(mole_name):
     # print(r.text)
 
     os.remove(newname)
-       
+
 
 def put_conformers(folder: str):
     mole_full_name = os.path.basename(folder).strip()
@@ -282,20 +282,20 @@ def get_att(mole_name_folder: str):
     (dirname, basename) = parse_folder_name(os.path.join(os.path.curdir,mole_name_folder))
     # (dirname, basename) = parse_folder_name(mole_name_folder)
     payload = {'mole_name': basename}
-    
-    
+
+
     r = requests.get(API_ADDRESS+'/get_att/', params=payload, stream=True)
-       
+
     if r.text == 'error':
         print("molecule " + basename+" does not have attachments in database")
         exit(-1)
-        return "error" 
+        return "error"
     os.chdir(dirname)
     # print(dirname)
     # print(basename)
     with open(basename+'.zip','wb') as f:
         f.write(r.content)
-    
+
     unzip(basename+'.zip')
     os.remove(basename+'.zip')
 
@@ -309,16 +309,27 @@ def get_by_energy(mole_folder: str, energy_level: float):
 @app.command()
 def ls():
   # Initialize a client & load the schema document
-    client = coreapi.Client()
-    schema = client.get(API_ADDRESS+'/docs/')
+    # client = coreapi.Client()
+    # schema = client.get(API_ADDRESS+'/docs/')
 
-    # Interact with the API endpoint
-    action = ["molecules", "list"]
-    result = client.action(schema, action)
-    for i in result:
+    # # Interact with the API endpoint
+    # action = ["molecules", "list"]
+    # result = client.action(schema, action)
+    # for i in result:
+    #     print(i['molecule_name'])
+
+
+    # payload = {'mole_name': basename}
+    r = requests.get(API_ADDRESS+'//molecules/', stream=True)
+
+    if r.text == 'error':
+        print("molecule list error")
+        exit(-1)
+        return "error"
+    ans = json.loads(r.text)
+    for i in ans:
         print(i['molecule_name'])
 
-
 @app.command()
 def trans(folder):
     os.chdir(folder)
